"""Generate tools and prompt from SaaSModel."""

from foremet.generate.prompt import generate_system_prompt, write_generated_prompt
from foremet.generate.tools import generate_tools, write_generated_tools

__all__ = ["generate_tools", "generate_system_prompt", "write_generated_tools", "write_generated_prompt"]
