"""LangGraph state for the agent."""

from typing import Annotated, TypedDict

from langchain_core.messages import BaseMessage
from langgraph.graph.message import add_messages


class AgentState(TypedDict):
    """State: messages list (append-only)."""
    messages: Annotated[list[BaseMessage], add_messages]
